@@ -57,14 +57,12 @@ class TableHandlerInterface(object):
         '''
         raise NotImplementedError
 
-    def column_rename(self, old_name, new_name, exception=False):
+    def column_rename(self, old_name, new_name):
         '''
-        Rename column
+        Rename column if exists
 
         :param old_name: the name of the existing column
         :param new_name: the new name of the column
-        :param exception: a boolean to raise or not an exception
-            if it is not possible to rename the column.
         '''
         raise NotImplementedError
 
@@ -86,6 +84,19 @@ class TableHandlerInterface(object):
         '''
         raise NotImplementedError
 
+    def column_is_type(self, column_name, type_, *, size=-1):
+        '''
+        Return True if the column is of type type_
+
+        :param column_name: the column name
+        :param type_: the generic name of the type
+        :param size: if `type` is VARCHAR you can specify its size.
+                     Use a negative value to ignore the size check.
+                     Defaults to -1
+        :return: a boolean
+        '''
+        raise NotImplementedError
+
     def db_default(self, column_name, value):
         '''
         Set a default on a column
@@ -125,12 +136,13 @@ class TableHandlerInterface(object):
         '''
         raise NotImplementedError
 
-    def index_action(self, column_name, action='add', table=None):
+    def index_action(self, columns, action='add', where=None, table=None):
         '''
         Add/remove an index
 
-        :param column_name: the column name or a list of column name
+        :param columns: the column or a list of columns/expressions
         :param action: 'add' or 'remove'
+        :param where: predicate expression
         :param table: optional table name
         '''
         raise NotImplementedError
@@ -144,35 +156,29 @@ class TableHandlerInterface(object):
         '''
         raise NotImplementedError
 
-    def add_constraint(self, ident, constraint, exception=False):
+    def add_constraint(self, ident, constraint):
         '''
         Add a constraint
 
         :param ident: the name of the constraint
         :param constraint: the definition of the constraint
-        :param exception: a boolean to raise or not an exception
-            if it is not possible to add the constraint
         '''
         raise NotImplementedError
 
-    def drop_constraint(self, ident, exception=False, table=None):
+    def drop_constraint(self, ident, table=None):
         '''
         Remove a constraint
 
         :param ident: the name of the constraint
-        :param exception: a boolean to raise or not an exception
-            if it is not possible to remove the constraint
         :param table: optional table name
         '''
         raise NotImplementedError
 
-    def drop_column(self, column_name, exception=False):
+    def drop_column(self, column_name):
         '''
         Remove a column
 
         :param column_name: the column name
-        :param exception: a boolean to raise or not an exception
-            if it is not possible to remove the column
         '''
         raise NotImplementedError
 
@@ -195,7 +201,7 @@ class TableHandlerInterface(object):
         :param name: the data name
         '''
         if cls.namedatalen and len(name) >= cls.namedatalen:
-            if isinstance(name, unicode):
+            if isinstance(name, str):
                 name = name.encode('utf-8')
             name = hashlib.sha256(name).hexdigest()[:cls.namedatalen - 1]
         return name
