@@ -21,8 +21,7 @@ class Configuration(ModelSingleton, ModelSQL):
         language = cls._get_language_cache.get(None)
         if language is not None:
             return language
-        config = cls(1)
-        language = config.language
+        language = cls(1).language
         if not language:
             language = config.get('database', 'language')
         cls._get_language_cache.set(None, language)
