@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+from trytond.pyson import PYSONEncoder, PYSON
 from .field import Field
-from ...pyson import PYSON
 
 
 def digits_validate(value):
@@ -21,6 +21,7 @@ class Float(Field):
     '''
     _type = 'float'
     _sql_type = 'FLOAT'
+    _py_type = float
 
     def __init__(self, string='', digits=None, help='', required=False,
             readonly=False, domain=None, states=None, select=False,
@@ -48,7 +49,8 @@ class Float(Field):
 
     digits = property(_get_digits, _set_digits)
 
-    def sql_format(self, value):
-        if value is None:
-            return None
-        return float(value)
+    def definition(self, model, language):
+        encoder = PYSONEncoder()
+        definition = super().definition(model, language)
+        definition['digits'] = encoder.encode(self.digits)
+        return definition
