@@ -1307,13 +1307,10 @@ class ModelStorage(Model):
                             or not digits
                             or any(d is None for d in digits)):
                         return
-                    if isinstance(value, Decimal):
-                        exp = Decimal('.'.join(['0', '0' * digits[1]]))
-                        if value.quantize(exp) != value:
-                            raise_error(value)
-                    else:
-                        if not (round(value, digits[1]) == float(value)):
-                            raise_error(value)
+                    if (round(value, digits[1]) != value
+                            or (isinstance(value, Decimal)
+                                and value.as_tuple().exponent < -digits[1])):
+                        raise_error(value)
                 # validate digits
                 if getattr(field, 'digits', None):
                     if is_pyson(field.digits):
@@ -1667,7 +1664,8 @@ class ModelStorage(Model):
                 read_data = self.read(list(index.keys()), list(ffields.keys()))
                 read_data.sort(key=lambda r: index[r['id']])
             # create browse records for 'remote' models
-            no_local_cache = {'one2one', 'one2many', 'many2many', 'binary'}
+            no_local_cache = {
+                'one2one', 'one2many', 'many2many', 'binary', 'reference'}
             for data in read_data:
                 id_ = data['id']
                 to_delete = set()
