@@ -9,6 +9,8 @@ import time
 from collections import namedtuple
 from contextlib import contextmanager
 
+from trytond.config import config
+
 status = dict()
 logger = logging.getLogger(__name__)
 address = 'trytond-stat.socket'
@@ -16,13 +18,12 @@ address = 'trytond-stat.socket'
 Process = namedtuple('Process', ['start_time', 'request'])
 
 _PID = None
-_PATH = None
 _LOCK = threading.Lock()
 
 
 @contextmanager
 def processing(request):
-    start(_PATH)  # check if running thread
+    start()  # check if running thread
     process = Process(time.perf_counter(), request)
     status[id(process)] = process
     try:
@@ -73,17 +74,17 @@ def dumper(path):
             time.sleep(60)
 
 
-def start(path):
-    global _PID, _PATH
+def start():
+    global _PID
     if not hasattr(socket, 'AF_UNIX'):
         return
-    if _PID != os.getpid() and path:  # Quick test without lock
+    if _PID != os.getpid():  # Quick test without lock
         with _LOCK:
             if _PID != os.getpid():
+                path = config.get('database', 'path')
                 threading.Thread(
                     target=dumper, args=(path,), daemon=True).start()
                 _PID = os.getpid()
-                _PATH = path
 
 
 def listen(path, callback=None):
