@@ -4,14 +4,11 @@
 from sql import Null
 from sql.conditionals import Case
 
-from trytond.model import ModelView, ModelSQL, fields
-
-__all__ = [
-    'MPTT',
-    ]
+from trytond.model import ModelView, ModelSQL, DeactivableMixin, tree, fields
+from trytond.pool import Pool
 
 
-class MPTT(ModelSQL, ModelView):
+class MPTT(DeactivableMixin, tree(), ModelSQL, ModelView):
     'Modified Preorder Tree Traversal'
     __name__ = 'test.mptt'
     name = fields.Char('Name', required=True)
@@ -20,22 +17,12 @@ class MPTT(ModelSQL, ModelView):
     left = fields.Integer('Left', required=True, select=True)
     right = fields.Integer('Right', required=True, select=True)
     childs = fields.One2Many('test.mptt', 'parent', 'Children')
-    active = fields.Boolean('Active')
-
-    @classmethod
-    def validate(cls, record):
-        super(MPTT, cls).validate(record)
-        cls.check_recursion(record)
 
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
         return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
-    @staticmethod
-    def default_active():
-        return True
-
     @staticmethod
     def default_left():
         return 0
@@ -43,3 +30,9 @@ class MPTT(ModelSQL, ModelView):
     @staticmethod
     def default_right():
         return 0
+
+
+def register(module):
+    Pool.register(
+        MPTT,
+        module=module, type_='model')
