@@ -3,10 +3,10 @@
 import unittest
 import datetime
 
+from trytond.model.exceptions import AccessError
 from trytond.tests.test_tryton import activate_module, with_transaction
 from trytond.transaction import Transaction
 from trytond.pool import Pool
-from trytond.exceptions import UserError
 from trytond import backend
 
 
@@ -73,9 +73,10 @@ class HistoryTestCase(unittest.TestCase):
                 self.assertEqual(history.value, value)
 
         with Transaction().set_context(_datetime=datetime.datetime.min):
-            self.assertRaises(UserError, History.read, [history_id])
+            with self.assertRaises(AccessError):
+                History.read([history_id], ['value'])
 
-    @unittest.skipUnless(backend.name() == 'postgresql',
+    @unittest.skipUnless(backend.name == 'postgresql',
         'CURRENT_TIMESTAMP as transaction_timestamp is specific to postgresql')
     @with_transaction()
     def test_read_same_timestamp(self):
@@ -142,9 +143,9 @@ class HistoryTestCase(unittest.TestCase):
 
         revisions = History.history_revisions([history_id])
         self.assertEqual(revisions, [
-                (third, history_id, u'Administrator'),
-                (second, history_id, u'Administrator'),
-                (first, history_id, u'Administrator'),
+                (third, history_id, 'Administrator'),
+                (second, history_id, 'Administrator'),
+                (first, history_id, 'Administrator'),
                 ])
 
     @with_transaction()
@@ -174,7 +175,8 @@ class HistoryTestCase(unittest.TestCase):
         transaction.rollback()
 
         History.restore_history([history_id], datetime.datetime.min)
-        self.assertRaises(UserError, History.read, [history_id])
+        with self.assertRaises(AccessError):
+            History.read([history_id], ['value'])
 
         transaction.rollback()
 
@@ -183,7 +185,8 @@ class HistoryTestCase(unittest.TestCase):
         transaction.commit()
 
         History.restore_history([history_id], datetime.datetime.max)
-        self.assertRaises(UserError, History.read, [history_id])
+        with self.assertRaises(AccessError):
+            History.read([history_id], ['value'])
 
     @with_transaction()
     def test_restore_history_before(self):
@@ -215,7 +218,7 @@ class HistoryTestCase(unittest.TestCase):
         history = History(history_id)
         self.assertEqual(history.value, 1)
 
-    @unittest.skipUnless(backend.name() == 'postgresql',
+    @unittest.skipUnless(backend.name == 'postgresql',
         'CURRENT_TIMESTAMP as transaction_timestamp is specific to postgresql')
     @with_transaction()
     def test_restore_history_same_timestamp(self):
@@ -311,7 +314,7 @@ class HistoryTestCase(unittest.TestCase):
                 self.assertEqual(records, instances)
             transaction.rollback()
 
-    @unittest.skipUnless(backend.name() == 'postgresql',
+    @unittest.skipUnless(backend.name == 'postgresql',
         'CURRENT_TIMESTAMP as transaction_timestamp is specific to postgresql')
     @with_transaction()
     def test_ordered_search_same_timestamp(self):
@@ -465,7 +468,7 @@ class HistoryTestCase(unittest.TestCase):
         transaction = Transaction()
         database = transaction.database
 
-        for i in xrange(0, 2):
+        for i in range(0, 2):
             history = History(value=-1)
             history.save()
 
