@@ -35,7 +35,8 @@ class RoutesTestCase(unittest.TestCase):
     @property
     def auth_headers(self):
         return {
-            'Authorization': b'Basic ' + base64.b64encode(b'admin:password'),
+            'Authorization': (
+                'Basic ' + base64.b64encode(b'admin:password').decode()),
             }
 
     def data_url(self, model):
