@@ -3,7 +3,7 @@
 import smtplib
 import unittest
 from email.message import Message
-from unittest.mock import Mock, patch, call
+from unittest.mock import ANY, Mock, MagicMock, patch, call
 
 from trytond.sendmail import (
     sendmail_transactional, sendmail, SMTPDataManager, get_smtp_server)
@@ -21,7 +21,7 @@ class SendmailTestCase(unittest.TestCase):
     @with_transaction()
     def test_sendmail_transactional(self):
         'Test sendmail_transactional'
-        message = Mock()
+        message = MagicMock()
         datamanager = Mock()
         sendmail_transactional(
             'tryton@example.com', 'foo@example.com', message,
@@ -32,7 +32,7 @@ class SendmailTestCase(unittest.TestCase):
 
     def test_sendmail(self):
         'Test sendmail'
-        message = Mock()
+        message = MagicMock()
         server = Mock()
         sendmail(
             'tryton@example.com', 'foo@example.com', message, server=server)
@@ -58,14 +58,14 @@ class SendmailTestCase(unittest.TestCase):
             SMTP.return_value = server = Mock()
             self.assertEqual(
                 get_smtp_server('smtps://localhost:25'), server)
-            SMTP.assert_called_once_with('localhost', 25)
+            SMTP.assert_called_once_with('localhost', 25, context=ANY)
 
         with patch.object(smtplib, 'SMTP') as SMTP:
             SMTP.return_value = server = Mock()
             self.assertEqual(
                 get_smtp_server('smtp+tls://localhost:25'), server)
             SMTP.assert_called_once_with('localhost', 25)
-            server.starttls.assert_called_once_with()
+            server.starttls.assert_called_once_with(context=ANY)
 
     def test_get_smtp_server_extra_parameters(self):
         'Test get_smtp_server uri extra parameters'
@@ -89,8 +89,8 @@ class SendmailTestCase(unittest.TestCase):
         # multiple join must return the same
         self.assertEqual(transaction.join(SMTPDataManager()), datamanager)
 
-        msg1 = Mock(Message)
-        msg2 = Mock(Message)
+        msg1 = MagicMock(Message)
+        msg2 = MagicMock(Message)
         datamanager.put('foo@example.com', 'bar@example.com', msg1)
         datamanager.put('bar@example.com', 'foo@example.com', msg2)
 
@@ -105,7 +105,8 @@ class SendmailTestCase(unittest.TestCase):
 
         server.reset_mock()
 
-        datamanager.put('foo@example.com', 'bar@example.com', Mock(Message))
+        datamanager.put(
+            'foo@example.com', 'bar@example.com', MagicMock(Message))
         transaction.rollback()
 
         server.sendmail.assert_not_called()
