@@ -1,7 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import unittest
-from mock import Mock
+from unittest.mock import Mock
+
 from trytond.tests.test_tryton import DB_NAME, USER, CONTEXT, activate_module
 from trytond.transaction import Transaction
 
@@ -86,7 +87,7 @@ class TransactionTestCase(unittest.TestCase):
         dm.tpc_begin.assert_called_once_with(transaction)
         dm.commit.assert_called_once_with(transaction)
         dm.tpc_vote.assert_called_once_with(transaction)
-        dm.tpc_abort.not_called()
+        dm.tpc_abort.assert_not_called()
         dm.tpc_finish.assert_called_once_with(transaction)
 
         # Failing in the datamanager
