@@ -2,6 +2,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import doctest
+import hashlib
 import inspect
 import operator
 import os
@@ -102,8 +103,7 @@ def restore_db_cache(name):
 
 def backup_db_cache(name):
     if DB_CACHE:
-        if not os.path.exists(DB_CACHE):
-            os.makedirs(DB_CACHE)
+        os.makedirs(DB_CACHE, exist_ok=True)
         cache_file = _db_cache_file(DB_CACHE, name)
         if not os.path.exists(cache_file):
             if backend.name == 'sqlite':
@@ -113,7 +113,8 @@ def backup_db_cache(name):
 
 
 def _db_cache_file(path, name):
-    return os.path.join(path, '%s-%s.dump' % (name, backend.name))
+    hash_name = hashlib.shake_128(name.encode('utf8')).hexdigest(40 // 2)
+    return os.path.join(path, '%s-%s.dump' % (hash_name, backend.name))
 
 
 def _sqlite_copy(file_, restore=False):
